aboutsummaryrefslogtreecommitdiff
path: root/qa/rpc-tests/rpcbind_test.py
diff options
context:
space:
mode:
authorWladimir J. van der Laan <laanwj@gmail.com>2016-09-26 15:02:55 +0200
committerWladimir J. van der Laan <laanwj@gmail.com>2016-09-26 15:03:06 +0200
commitdd20ed1223b95fb2df99fa1d6b72810e5f693473 (patch)
tree42b744a74b3de38cd7006bb2e40c591ff63b5152 /qa/rpc-tests/rpcbind_test.py
parentbb843adc8d04bc64dc8823f11e904050c7376a59 (diff)
parentfa6e71b27d00766897f3e69775d450924a58a153 (diff)
downloadbitcoin-dd20ed1223b95fb2df99fa1d6b72810e5f693473.tar.xz
Merge #8780: [rpc] Deprecate getinfo
fa6e71b [qa] Add getinfo smoke tests and rework versionbits test (MarcoFalke) ddddaaf [rpc] Deprecate getinfo (MarcoFalke)
Diffstat (limited to 'qa/rpc-tests/rpcbind_test.py')
-rwxr-xr-xqa/rpc-tests/rpcbind_test.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/qa/rpc-tests/rpcbind_test.py b/qa/rpc-tests/rpcbind_test.py
index 3ac32140ba..085024e268 100755
--- a/qa/rpc-tests/rpcbind_test.py
+++ b/qa/rpc-tests/rpcbind_test.py
@@ -44,7 +44,7 @@ class RPCBindTest(BitcoinTestFramework):
def run_allowip_test(self, allow_ips, rpchost, rpcport):
'''
Start a node with rpcwallow IP, and request getinfo
at a non-localhost IP.
'''
base_args = ['-disablewallet', '-nolisten'] + ['-rpcallowip='+x for x in allow_ips]
@@ -52,7 +52,7 @@ class RPCBindTest(BitcoinTestFramework):
try:
# connect to node through non-loopback interface
node = get_rpc_proxy(rpc_url(0, "%s:%d" % (rpchost, rpcport)), 0)
- node.getinfo()
+ node.getnetworkinfo()
finally:
node = None # make sure connection will be garbage collected and closed
stop_nodes(self.nodes)
@@ -44,7 +44,7 @@ class RPCBindTest(BitcoinTestFramework):
def run_allowip_test(self, allow_ips, rpchost, rpcport):
'''
- Start a node with rpcwallow IP, and request getinfo
+ Start a node with rpcallow IP, and request getnetworkinfo
at a non-localhost IP.
'''